#!/Library/Frameworks/EPD64.framework/Versions/Current/bin/python

"""
File: Salix_dadi.py
Author: Michael G. Harvey

Created by Michael G. Harvey on 21 September 2012
Copyright (c) 2012 Michael G. Harvey. All rights reserved.

Description: run dadi (Gutenkunst et al. 2009) on frequency spectra 
generated from Salix melanopsis phylogeographic samples to evaluate 
models from Salix_dadi_models.py

"""


# Numpy is the numerical library dadi is built upon

import os, sys
import numpy
from numpy import array
import dadi
import matplotlib
import matplotlib.pyplot as plt
import Salix_models


# Select which models to run: 1 for yes, anything else for no

complete = 1
NSC-all = 1
SCN-all = 1
CSN-all = 1
SCN-Brunsfeld = 1
SCN-Miller = 1
SCN-Carstens = 1
SCN-noincrease = 1
SCN-noincrease_equaltheta_noM = 1
SCN-equaltheta = 1
SCN-noincrease_equaltheta = 1
SCN-noincrease_noM = 1
SCN-noM_equaltheta = 1
two_pop_CN_S = 1
two_pop_C_NS = 1
two_pop_N_CS = 1


# Make directories for each model to be tested

if NSC-all == 1:
    os.system("mkdir -p ./NSC-all") 
if SCN-all == 1:
    os.system("mkdir -p ./SCN-all") 
if CSN-all == 1:
    os.system("mkdir -p ./CSN-all") 
if SCN-Brunsfeld == 1:
    os.system("mkdir -p ./SCN-Brunsfeld")    
if SCN-Miller == 1:
    os.system("mkdir -p ./SCN-Miller")
if SCN-Carstens == 1:
    os.system("mkdir -p ./SCN-Carstens")    
if SCN-noincrease == 1:
    os.system("mkdir -p ./SCN-noincrease") 
if SCN-noincrease_equaltheta_noM == 1:
    os.system("mkdir -p ./SCN-noincrease_equaltheta_noM")    
if SCN-equaltheta == 1:
    os.system("mkdir -p ./SCN-equaltheta")    
if SCN-noincrease_equaltheta == 1:
    os.system("mkdir -p ./SCN-noincrease_equaltheta")    
if SCN-noincrease_noM == 1:
    os.system("mkdir -p ./SCN-noincrease_noM")
if SCN-noM_equaltheta == 1:
    os.system("mkdir -p ./SCN-noM_equaltheta")
if two_pop_CN_S == 1:
    os.system("mkdir -p ./two_pop_CN_S")
if two_pop_C_NS == 1:
    os.system("mkdir -p ./two_pop_C_NS")
if two_pop_N_CS == 1:
    os.system("mkdir -p ./two_pop_N_CS")
    

# Load frequency spectra (data)

data = dadi.Spectrum.from_file('Salix.fs')
data2 = dadi.Spectrum.from_file('Salix_Nbasal.fs')
data3 = dadi.Spectrum.from_file('Salix_2D_A.fs')
data4 = dadi.Spectrum.from_file('Salix_2D_C.fs')
data5 = dadi.Spectrum.from_file('Salix_2D_B.fs')
ns = data.sample_sizes
pts_l = [30,40,50]


# Evaluate models (calculate likelihood, optimize parameters, print figures)


"""
NSC-all

"""

if NSC-all == 1:

    print "--NSC-all--"
    
    func = Salix_dadi_models.NSC-all
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.0, 1.4, 4.5, 4.5])
    upper_bound = [10, 2, 10, 5, 3, 3, 3, 20, 20, 20]
    lower_bound = [0.0001, 0.0001, 0.0001, 0.0001, 0, 0, 0, 0.0001, 0.0001, 0.0001]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data2)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data2) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data2, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data2)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
    
    os.system("echo '%f' > ./NSC-all/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./NSC-all/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data2, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./NSC-all/fscomparisons.png')


"""
SCN-all

"""

if SCN-all == 1:

    print "--SCN-all--"
    
    func = Salix_dadi_models.SCN-all
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.0, 1.4, 4.5, 4.5])
    upper_bound = [10, 2, 10, 5, 3, 3, 3, 20, 20, 20]
    lower_bound = [0.0001, 0.0001, 0.0001, 0.0001, 0, 0, 0, 0.0001, 0.0001, 0.0001]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
    
    os.system("echo '%f' > ./SCN-all/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-all/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-all/fscomparisons.png')


"""
CSN-all

"""

if CSN-all == 1:

    print "--CSN-all--"
    
    func = Salix_dadi_models.CSN-all
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.0, 1.4, 4.5, 4.5])
    upper_bound = [10, 2, 10, 5, 3, 3, 3, 20, 20, 20]
    lower_bound = [0.0001, 0.0001, 0.0001, 0.0001, 0, 0, 0, 0.0001, 0.0001, 0.0001]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
    
    os.system("echo '%f' > ./CSN-all/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./CSN-all/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./CSN-all/fscomparisons.png')
    

"""
SCN-Brunsfeld

"""

if SCN-Brunsfeld == 1:

    print "--SCN-Brunsfeld--"
    
    func = Salix_models_2.SCN-Brunsfeld
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.4, 1.4, 1.4])
    upper_bound = [5, 10, 10, 10, 5, 5, 20, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.001, 0, 0, 0.01, 0.01, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-Brunsfeld/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-Brunsfeld/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-Brunsfeld/fscomparisons.png')


"""
SCN-Miller

"""

if SCN-Miller == 1:

    print "--SCN-Miller--"
    
    func = Salix_models_2.SCN-Miller
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.4, 1.4, 1.4])
    upper_bound = [5, 10, 10, 10, 5, 5, 20, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.001, 0, 0, 0.01, 0.01, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-Miller/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-Miller/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-Miller/fscomparisons.png')
    

"""
SCN-Carstens

"""

if SCN-Carstens == 1:

    print "--SCN-Carstens--"
    
    func = Salix_dadi_models.SCN-Carstens
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.0, 1.0, 1.4, 4.5, 4.5])
    upper_bound = [5, 10, 10, 10, 5, 5, 5, 5, 20, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.001, 0, 0, 0, 0, 0.1, 0.1, 0.1]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-Carstens/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-Carstens/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-Carstens/fscomparisons.png')
    

"""
SCN-noincrease

"""

if SCN-noincrease == 1:

    print "--SCN-noincrease--"
    
    func = Salix_dadi_models.SCN-noincrease
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.0, 1.4, 4.5, 4.5])
    upper_bound = [5, 10, 10, 10, 5, 5, 5, 20, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.001, 0, 0, 0, 0.01, 0.01, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=1000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-noincrease/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-noincrease/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-noincrease/fscomparisons.png')
    
    
"""
SCN-noincrease_equaltheta_noM

"""

if SCN-noincrease_equaltheta_noM == 1:

    print "--SCN-noincrease_equaltheta_noM--"
    
    func = Salix_dadi_models.SCN-noincrease_equaltheta_noM
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 1.4])
    upper_bound = [5, 10, 10, 10, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.001, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-noincrease_equaltheta_noM/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-noincrease_equaltheta_noM/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-noincrease_equaltheta_noM/fscomparisons.png')
      

"""
SCN-equaltheta

"""

if SCN-equaltheta == 1:

    print "--SCN-equaltheta--"
    
    func = Salix_dadi_models.SCN-equaltheta
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.0, 4.5])
    upper_bound = [5, 10, 10, 10, 5, 5, 5, 20]
    lower_bound = [0.001, 0.0001, 0.0001, 0.0001, 0, 0, 0, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-equaltheta/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-equaltheta/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-equaltheta/fscomparisons.png')    
    
    
"""
SCN-noincrease_equaltheta

"""

if SCN-noincrease_equaltheta == 1:

    print "--SCN-noincrease_equaltheta--"
    
    func = Salix_dadi_models.SCN-noincrease_equaltheta
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 0.6, 1.6, 1.0, 1.4])
    upper_bound = [5, 10, 10, 10, 5, 5, 5, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.001, 0, 0, 0, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-noincrease_equaltheta/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-noincrease_equaltheta/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-noincrease_equaltheta/fscomparisons.png')    
    

"""
SCN-noincrease_noM

"""

if SCN-noincrease_noM == 1:

    print "--SCN-noincrease_noM--"
    
    func = Salix_dadi_models.SCN-noincrease_noM
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 6.3, 0.4, 1.4, 4.5, 4.5])
    upper_bound = [5, 10, 10, 20, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.01, 0.01, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-noincrease_noM/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-noincrease_noM/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-noincrease_noM/fscomparisons.png')


"""
SCN-noM_equaltheta

"""

if SCN-noM_equaltheta == 1:

    print "--SCN-noM_equaltheta--"
    
    func = Salix_dadi_models.SCN-noM_equaltheta
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.4, 1.4])
    upper_bound = [5, 10, 10, 10, 20]
    lower_bound = [0.01, 0.001, 0.001, 0.001, 0.01]

    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
        
    os.system("echo '%f' > ./SCN-noM_equaltheta/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./SCN-noM_equaltheta/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_3d_comp_multinom(model, data, vmin=1, resid_range=3, pop_ids =('p1','p2','p3'))
    fig.savefig('./SCN-noM_equaltheta/fscomparisons.png')


"""
two_pop_CN_S

"""

if two_pop_CN_S == 1:

    print "--two_pop_CN_S--"
    
    func = Salix_models.two_pop_CN_S
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.6, 1.6, 1.4, 4.5])
    upper_bound = [5, 10, 10, 5, 5, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0, 0, 0.1, 0.1]
    
    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data3)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data3) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data3, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data3)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
    
    os.system("echo '%f' > ./two_pop_CN_S/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./two_pop_CN_S/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_2d_comp_multinom(model, data3, vmin=1, resid_range=3, pop_ids =('p1','p2'))
    fig.savefig('./two_pop_CN_S/fscomparisons.png', dpi=50)


"""
two_pop_C_NS

"""

if two_pop_C_NS == 1:

    print "--two_pop_C_NS--"
    
    func = Salix_models.two_pop_C_NS
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.6, 1.6, 1.4, 4.5])
    upper_bound = [5, 10, 10, 5, 5, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0, 0, 0.1, 0.1]
    
    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data4)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data4) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data4, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data4)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
     
    os.system("echo '%f' > ./two_pop_C_NS/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./two_pop_C_NS/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_2d_comp_multinom(model, data4, vmin=1, resid_range=3, pop_ids =('p1','p2'))
    fig.savefig('./two_pop_C_NS/fscomparisons.png', dpi=50)


"""
two_pop_N_CS

"""

if two_pop_N_CS == 1:

    print "--two_pop_N_CS--"
    
    func = Salix_models.two_pop_N_CS
    # Starting values based on parameters from an abbreviated preliminary run of model "SCN-all".
    params = array([0.1, 1.6, 4.7, 0.6, 1.6, 1.4, 4.5])
    upper_bound = [5, 10, 10, 5, 5, 20, 20]
    lower_bound = [0.01, 0.001, 0.001, 0, 0, 0.1, 0.1]
    
    func_ex = dadi.Numerics.make_extrap_log_func(func)
    model = func_ex(params, ns, pts_l)
    ll_model = dadi.Inference.ll_multinom(model, data5)
    print 'Model log-likelihood:', ll_model
    theta = dadi.Inference.optimal_sfs_scaling(model, data5) 

    ## Optimization
    p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
    popt = dadi.Inference.optimize_log(p0, data5, func_ex, pts_l, 
                                       lower_bound=lower_bound,
                                       upper_bound=upper_bound,
                                       verbose=len(params), maxiter=5000)
    print 'Optimized parameters', repr(popt)
    model = func_ex(popt, ns, pts_l)
    ll_opt = dadi.Inference.ll_multinom(model, data5)
    print 'Optimized log-likelihood:', ll_opt
    optpar = repr(popt)
     
    os.system("echo '%f' > ./two_pop_N_CS/optimized_output.txt" % (ll_opt))
    os.system("echo '%s' >> ./two_pop_N_CS/optimized_output.txt" % (optpar))

    # Plot a comparison of the resulting fs with the data and save to file.
    plt.ion()
    fig = plt.figure()
    dadi.Plotting.plot_2d_comp_multinom(model, data5, vmin=1, resid_range=3, pop_ids =('p1','p2'))
    fig.savefig('./two_pop_N_CS/fscomparisons.png', dpi=50)






