#!/Library/Frameworks/EPD64.framework/Versions/Current/bin/python

"""
File: fs_from_nex.py
Author: Michael G. Harvey

Created by Michael G. Harvey on 21 September 2012
Copyright (c) 2012 Michael G. Harvey. All rights reserved.

Description: generate multi-population allele frequency spectra from SNPs in Salix
melanopsis alignments

NOTE: This script relies on a custom script "NeXus.py" written by R. Gutenkunst 
specifically for use with alignments in nexus format.

"""

import dadi
import NeXus


"""
Generate frequency spectrum for three populations with Salmon or Clearwater basal.

"""

# Population assignments
#
# p1 = Salmon drainage
# p2 = Clearwater drainage
# p3 = northern drainages
# p4 = Cascades

if __name__ == '__main__':
    pop_assignments = {'trm82dxxxx_a':'p2',
                       'trm82dxxxx_b':'p2',
                       'trm56exxxx_a':'p4',
                       'trm56exxxx_b':'p4',
                       'trm48dxxxx_a':'p2',
                       'trm48dxxxx_b':'p2',
                       'sjb7102gxx_a':'p1',
                       'sjb7102gxx_b':'p1',
                       'trm34exxxx_a':'p3',
                       'trm34exxxx_b':'p3',
                       'trm69exxxx_a':'p2',
                       'trm69exxxx_b':'p2',
                       'sjb7101axx_a':'p1',
                       'sjb7101axx_b':'p1',
                       'trm42axxxx_a':'p2',
                       'trm42axxxx_b':'p2',
                       'trm54bxxxx_a':'p4',
                       'trm54bxxxx_b':'p4',
                       'trm40cxxxx_a':'p2',
                       'trm40cxxxx_b':'p2',
                       'trm60bxxxx_a':'p4',
                       'trm60bxxxx_b':'p4',
                       'trm32bxxxx_a':'p3',
                       'trm32bxxxx_b':'p3',
                       'trm37dxxxx_a':'p3',
                       'trm37dxxxx_b':'p3',
                       'trm71exxxx_a':'p2',
                       'trm71exxxx_b':'p2',
                       'trm34cxxxx_a':'p3',
                       'trm34cxxxx_b':'p3',
                       'sjb7102bxx_a':'p1',
                       'sjb7102bxx_b':'p1',
                       'trm42cxxxx_a':'p2',
                       'trm42cxxxx_b':'p2',
                       'trm26dxxxx_a':'p3',
                       'trm26dxxxx_b':'p3',
                       'trm54jxxxx_a':'p4',
                       'trm54jxxxx_b':'p4',
                       'trm35dxxxx_a':'p3',
                       'trm35dxxxx_b':'p3',
                       'trm30bxxxx_a':'p3',
                       'trm30bxxxx_b':'p3',
                       'trm58axxxx_a':'p4',
                       'trm58axxxx_b':'p4',
                       'trm58dxxxx_a':'p4',
                       'trm58dxxxx_b':'p4',
                       'trm81bxxxx_a':'p2',
                       'trm81bxxxx_b':'p2',
                       'trm48jxxxx_a':'p2',
                       'trm48jxxxx_b':'p2',
                       'trm56fxxxx_a':'p4',
                       'trm56fxxxx_b':'p4',
                       'trm60axxxx_a':'p4',
                       'trm60axxxx_b':'p4',
                       'trm79axxxx_a':'p2',
                       'trm79axxxx_b':'p2',
                       'trm69axxxx_a':'p2',
                       'trm69axxxx_b':'p2',
                       'trm28dxxxx_a':'p3',
                       'trm28dxxxx_b':'p3',
                       'trm56bxxxx_a':'p4',
                       'trm56bxxxx_b':'p4',
                       'trm32cxxxx_a':'p3',
                       'trm32cxxxx_b':'p3',
                       'trm40bxxxx_a':'p2',
                       'trm40bxxxx_b':'p2',
                       'trm26bxxxx_a':'p3',
                       'trm26bxxxx_b':'p3',
                       'trm37cxxxx_a':'p3',
                       'trm37cxxxx_b':'p3',
                       'sjb7101bxx_a':'p1',
                       'sjb7101bxx_b':'p1',
                       'sjb7102exx_a':'p1',
                       'sjb7102exx_b':'p1',
                       'trm30exxxx_a':'p3',
                       'trm30exxxx_b':'p3',
                       'Salbaxxxxx_a':'outgroup',
                       }

    # Generate data dictionary from NeXus alignment

    dd = NeXus.data_dict_from_file('Concatenated_alignment_variable.nex', pop_assignments)
    
    # Generate frequency spectrum from data dictionary
    
    fs = dadi.Spectrum.from_data_dict(dd, ['p1', 'p2', 'p3'], [8,8,8])
    
    # Plot the fs
    import pylab
    dadi.Plotting.plot_3d_spectrum(fs, vmin=0.1)
    pylab.show()
    
    # Print fs to file
    
    fs.tofile('Salix.fs')

"""
Generate frequency spectrum for 3 populations with Northern Drainages basal.

"""

# For this script, population assignments different:
#
# p1 = Northern Drainages
# p2 = Clearwater Drainage
# p3 = Salmon Drainage
# p4 = Cascades


if __name__ == '__main__':
    pop_assignments = {'trm82dxxxx_a':'p2',
                       'trm82dxxxx_b':'p2',
                       'trm56exxxx_a':'p4',
                       'trm56exxxx_b':'p4',
                       'trm48dxxxx_a':'p2',
                       'trm48dxxxx_b':'p2',
                       'sjb7102gxx_a':'p3',
                       'sjb7102gxx_b':'p3',
                       'trm34exxxx_a':'p1',
                       'trm34exxxx_b':'p1',
                       'trm69exxxx_a':'p2',
                       'trm69exxxx_b':'p2',
                       'sjb7101axx_a':'p3',
                       'sjb7101axx_b':'p3',
                       'trm42axxxx_a':'p2',
                       'trm42axxxx_b':'p2',
                       'trm54bxxxx_a':'p4',
                       'trm54bxxxx_b':'p4',
                       'trm40cxxxx_a':'p2',
                       'trm40cxxxx_b':'p2',
                       'trm60bxxxx_a':'p4',
                       'trm60bxxxx_b':'p4',
                       'trm32bxxxx_a':'p1',
                       'trm32bxxxx_b':'p1',
                       'trm37dxxxx_a':'p1',
                       'trm37dxxxx_b':'p1',
                       'trm71exxxx_a':'p2',
                       'trm71exxxx_b':'p2',
                       'trm34cxxxx_a':'p1',
                       'trm34cxxxx_b':'p1',
                       'sjb7102bxx_a':'p3',
                       'sjb7102bxx_b':'p3',
                       'trm42cxxxx_a':'p2',
                       'trm42cxxxx_b':'p2',
                       'trm26dxxxx_a':'p1',
                       'trm26dxxxx_b':'p1',
                       'trm54jxxxx_a':'p4',
                       'trm54jxxxx_b':'p4',
                       'trm35dxxxx_a':'p1',
                       'trm35dxxxx_b':'p1',
                       'trm30bxxxx_a':'p1',
                       'trm30bxxxx_b':'p1',
                       'trm58axxxx_a':'p4',
                       'trm58axxxx_b':'p4',
                       'trm58dxxxx_a':'p4',
                       'trm58dxxxx_b':'p4',
                       'trm81bxxxx_a':'p2',
                       'trm81bxxxx_b':'p2',
                       'trm48jxxxx_a':'p2',
                       'trm48jxxxx_b':'p2',
                       'trm56fxxxx_a':'p4',
                       'trm56fxxxx_b':'p4',
                       'trm60axxxx_a':'p4',
                       'trm60axxxx_b':'p4',
                       'trm79axxxx_a':'p2',
                       'trm79axxxx_b':'p2',
                       'trm69axxxx_a':'p2',
                       'trm69axxxx_b':'p2',
                       'trm28dxxxx_a':'p1',
                       'trm28dxxxx_b':'p1',
                       'trm56bxxxx_a':'p4',
                       'trm56bxxxx_b':'p4',
                       'trm32cxxxx_a':'p1',
                       'trm32cxxxx_b':'p1',
                       'trm40bxxxx_a':'p2',
                       'trm40bxxxx_b':'p2',
                       'trm26bxxxx_a':'p1',
                       'trm26bxxxx_b':'p1',
                       'trm37cxxxx_a':'p1',
                       'trm37cxxxx_b':'p1',
                       'sjb7101bxx_a':'p3',
                       'sjb7101bxx_b':'p3',
                       'sjb7102exx_a':'p3',
                       'sjb7102exx_b':'p3',
                       'trm30exxxx_a':'p1',
                       'trm30exxxx_b':'p1',
                       'Salbaxxxxx_a':'outgroup',
                       }

    # Generate data dictionary from NeXus alignment

    dd = NeXus.data_dict_from_file('Concatenated_alignment_variable.nex', pop_assignments)
    
    # Generate frequency spectrum from data dictionary
    
    fs = dadi.Spectrum.from_data_dict(dd, ['p1', 'p2', 'p3'], [8,8,8])
    
    # Plot the fs
    #
    # import pylab
    # dadi.Plotting.plot_single_2d_sfs(fs, vmin=0.1)
    # pylab.show()
    
    # Print fs to file
    
    fs.tofile('Salix_Nbasal.fs')
    

"""
Generate frequency spectrum for 2 populations with Clearwater and Northern Drainages collapsed.

"""


if __name__ == '__main__':
    pop_assignments = {'trm82dxxxx_a':'p2',
                       'trm82dxxxx_b':'p2',
                       'trm56exxxx_a':'p4',
                       'trm56exxxx_b':'p4',
                       'trm48dxxxx_a':'p2',
                       'trm48dxxxx_b':'p2',
                       'sjb7102gxx_a':'p1',
                       'sjb7102gxx_b':'p1',
                       'trm34exxxx_a':'p2',
                       'trm34exxxx_b':'p2',
                       'trm69exxxx_a':'p2',
                       'trm69exxxx_b':'p2',
                       'sjb7101axx_a':'p1',
                       'sjb7101axx_b':'p1',
                       'trm42axxxx_a':'p2',
                       'trm42axxxx_b':'p2',
                       'trm54bxxxx_a':'p4',
                       'trm54bxxxx_b':'p4',
                       'trm40cxxxx_a':'p2',
                       'trm40cxxxx_b':'p2',
                       'trm60bxxxx_a':'p4',
                       'trm60bxxxx_b':'p4',
                       'trm32bxxxx_a':'p2',
                       'trm32bxxxx_b':'p2',
                       'trm37dxxxx_a':'p2',
                       'trm37dxxxx_b':'p2',
                       'trm71exxxx_a':'p2',
                       'trm71exxxx_b':'p2',
                       'trm34cxxxx_a':'p2',
                       'trm34cxxxx_b':'p2',
                       'sjb7102bxx_a':'p1',
                       'sjb7102bxx_b':'p1',
                       'trm42cxxxx_a':'p2',
                       'trm42cxxxx_b':'p2',
                       'trm26dxxxx_a':'p2',
                       'trm26dxxxx_b':'p2',
                       'trm54jxxxx_a':'p4',
                       'trm54jxxxx_b':'p4',
                       'trm35dxxxx_a':'p2',
                       'trm35dxxxx_b':'p2',
                       'trm30bxxxx_a':'p2',
                       'trm30bxxxx_b':'p2',
                       'trm58axxxx_a':'p4',
                       'trm58axxxx_b':'p4',
                       'trm58dxxxx_a':'p4',
                       'trm58dxxxx_b':'p4',
                       'trm81bxxxx_a':'p2',
                       'trm81bxxxx_b':'p2',
                       'trm48jxxxx_a':'p2',
                       'trm48jxxxx_b':'p2',
                       'trm56fxxxx_a':'p4',
                       'trm56fxxxx_b':'p4',
                       'trm60axxxx_a':'p4',
                       'trm60axxxx_b':'p4',
                       'trm79axxxx_a':'p2',
                       'trm79axxxx_b':'p2',
                       'trm69axxxx_a':'p2',
                       'trm69axxxx_b':'p2',
                       'trm28dxxxx_a':'p2',
                       'trm28dxxxx_b':'p2',
                       'trm56bxxxx_a':'p4',
                       'trm56bxxxx_b':'p4',
                       'trm32cxxxx_a':'p2',
                       'trm32cxxxx_b':'p2',
                       'trm40bxxxx_a':'p2',
                       'trm40bxxxx_b':'p2',
                       'trm26bxxxx_a':'p2',
                       'trm26bxxxx_b':'p2',
                       'trm37cxxxx_a':'p2',
                       'trm37cxxxx_b':'p2',
                       'sjb7101bxx_a':'p1',
                       'sjb7101bxx_b':'p1',
                       'sjb7102exx_a':'p1',
                       'sjb7102exx_b':'p1',
                       'trm30exxxx_a':'p2',
                       'trm30exxxx_b':'p2',
                       'Salbaxxxxx_a':'outgroup',
                       }

    # Generate data dictionary from NeXus alignment

    dd = NeXus.data_dict_from_file('Concatenated_alignment_variable.nex', pop_assignments)
    
    # Generate frequency spectrum from data dictionary
    
    fs = dadi.Spectrum.from_data_dict(dd, ['p1', 'p2'], [8,8])
    
    # Plot the fs
    import pylab
    dadi.Plotting.plot_single_2d_sfs(fs, vmin=0.1)
    pylab.show()
    
    # Print fs to file
    
    fs.tofile('Salix_2D_A.fs')    
    
    
"""
Generate frequency spectrum for 2 populations with Salmon and Northern Drainages collapsed.

"""    
    
    
if __name__ == '__main__':
    pop_assignments = {'trm82dxxxx_a':'p2',
                       'trm82dxxxx_b':'p2',
                       'trm56exxxx_a':'p4',
                       'trm56exxxx_b':'p4',
                       'trm48dxxxx_a':'p2',
                       'trm48dxxxx_b':'p2',
                       'sjb7102gxx_a':'p1',
                       'sjb7102gxx_b':'p1',
                       'trm34exxxx_a':'p1',
                       'trm34exxxx_b':'p1',
                       'trm69exxxx_a':'p2',
                       'trm69exxxx_b':'p2',
                       'sjb7101axx_a':'p1',
                       'sjb7101axx_b':'p1',
                       'trm42axxxx_a':'p2',
                       'trm42axxxx_b':'p2',
                       'trm54bxxxx_a':'p4',
                       'trm54bxxxx_b':'p4',
                       'trm40cxxxx_a':'p2',
                       'trm40cxxxx_b':'p2',
                       'trm60bxxxx_a':'p4',
                       'trm60bxxxx_b':'p4',
                       'trm32bxxxx_a':'p1',
                       'trm32bxxxx_b':'p1',
                       'trm37dxxxx_a':'p1',
                       'trm37dxxxx_b':'p1',
                       'trm71exxxx_a':'p2',
                       'trm71exxxx_b':'p2',
                       'trm34cxxxx_a':'p1',
                       'trm34cxxxx_b':'p1',
                       'sjb7102bxx_a':'p1',
                       'sjb7102bxx_b':'p1',
                       'trm42cxxxx_a':'p2',
                       'trm42cxxxx_b':'p2',
                       'trm26dxxxx_a':'p1',
                       'trm26dxxxx_b':'p1',
                       'trm54jxxxx_a':'p4',
                       'trm54jxxxx_b':'p4',
                       'trm35dxxxx_a':'p1',
                       'trm35dxxxx_b':'p1',
                       'trm30bxxxx_a':'p1',
                       'trm30bxxxx_b':'p1',
                       'trm58axxxx_a':'p4',
                       'trm58axxxx_b':'p4',
                       'trm58dxxxx_a':'p4',
                       'trm58dxxxx_b':'p4',
                       'trm81bxxxx_a':'p2',
                       'trm81bxxxx_b':'p2',
                       'trm48jxxxx_a':'p2',
                       'trm48jxxxx_b':'p2',
                       'trm56fxxxx_a':'p4',
                       'trm56fxxxx_b':'p4',
                       'trm60axxxx_a':'p4',
                       'trm60axxxx_b':'p4',
                       'trm79axxxx_a':'p2',
                       'trm79axxxx_b':'p2',
                       'trm69axxxx_a':'p2',
                       'trm69axxxx_b':'p2',
                       'trm28dxxxx_a':'p1',
                       'trm28dxxxx_b':'p1',
                       'trm56bxxxx_a':'p4',
                       'trm56bxxxx_b':'p4',
                       'trm32cxxxx_a':'p1',
                       'trm32cxxxx_b':'p1',
                       'trm40bxxxx_a':'p2',
                       'trm40bxxxx_b':'p2',
                       'trm26bxxxx_a':'p1',
                       'trm26bxxxx_b':'p1',
                       'trm37cxxxx_a':'p1',
                       'trm37cxxxx_b':'p1',
                       'sjb7101bxx_a':'p1',
                       'sjb7101bxx_b':'p1',
                       'sjb7102exx_a':'p1',
                       'sjb7102exx_b':'p1',
                       'trm30exxxx_a':'p1',
                       'trm30exxxx_b':'p1',
                       'Salbaxxxxx_a':'outgroup',
                       }


    # Generate data dictionary from NeXus alignment

    dd = NeXus.data_dict_from_file('Concatenated_alignment_variable.nex', pop_assignments)
    
    # Generate frequency spectrum from data dictionary
    
    fs = dadi.Spectrum.from_data_dict(dd, ['p1', 'p2'], [8,8])
    
    # Plot the fs
    #
    # import pylab
    # dadi.Plotting.plot_single_2d_sfs(fs, vmin=0.1)
    # pylab.show()
    
    # Print fs to file
    
    fs.tofile('Salix_2D_C.fs')
    
    
"""
Generate frequency spectrum for 2 populations with Clearwater and Salmon collapsed.

"""    
    
    
if __name__ == '__main__':
    pop_assignments = {'trm82dxxxx_a':'p1',
                       'trm82dxxxx_b':'p1',
                       'trm56exxxx_a':'p4',
                       'trm56exxxx_b':'p4',
                       'trm48dxxxx_a':'p1',
                       'trm48dxxxx_b':'p1',
                       'sjb7102gxx_a':'p1',
                       'sjb7102gxx_b':'p1',
                       'trm34exxxx_a':'p2',
                       'trm34exxxx_b':'p2',
                       'trm69exxxx_a':'p1',
                       'trm69exxxx_b':'p1',
                       'sjb7101axx_a':'p1',
                       'sjb7101axx_b':'p1',
                       'trm42axxxx_a':'p1',
                       'trm42axxxx_b':'p1',
                       'trm54bxxxx_a':'p4',
                       'trm54bxxxx_b':'p4',
                       'trm40cxxxx_a':'p1',
                       'trm40cxxxx_b':'p1',
                       'trm60bxxxx_a':'p4',
                       'trm60bxxxx_b':'p4',
                       'trm32bxxxx_a':'p2',
                       'trm32bxxxx_b':'p2',
                       'trm37dxxxx_a':'p2',
                       'trm37dxxxx_b':'p2',
                       'trm71exxxx_a':'p1',
                       'trm71exxxx_b':'p1',
                       'trm34cxxxx_a':'p2',
                       'trm34cxxxx_b':'p2',
                       'sjb7102bxx_a':'p1',
                       'sjb7102bxx_b':'p1',
                       'trm42cxxxx_a':'p1',
                       'trm42cxxxx_b':'p1',
                       'trm26dxxxx_a':'p2',
                       'trm26dxxxx_b':'p2',
                       'trm54jxxxx_a':'p4',
                       'trm54jxxxx_b':'p4',
                       'trm35dxxxx_a':'p2',
                       'trm35dxxxx_b':'p2',
                       'trm30bxxxx_a':'p2',
                       'trm30bxxxx_b':'p2',
                       'trm58axxxx_a':'p4',
                       'trm58axxxx_b':'p4',
                       'trm58dxxxx_a':'p4',
                       'trm58dxxxx_b':'p4',
                       'trm81bxxxx_a':'p1',
                       'trm81bxxxx_b':'p1',
                       'trm48jxxxx_a':'p1',
                       'trm48jxxxx_b':'p1',
                       'trm56fxxxx_a':'p4',
                       'trm56fxxxx_b':'p4',
                       'trm60axxxx_a':'p4',
                       'trm60axxxx_b':'p4',
                       'trm79axxxx_a':'p1',
                       'trm79axxxx_b':'p1',
                       'trm69axxxx_a':'p1',
                       'trm69axxxx_b':'p1',
                       'trm28dxxxx_a':'p2',
                       'trm28dxxxx_b':'p2',
                       'trm56bxxxx_a':'p4',
                       'trm56bxxxx_b':'p4',
                       'trm32cxxxx_a':'p2',
                       'trm32cxxxx_b':'p2',
                       'trm40bxxxx_a':'p1',
                       'trm40bxxxx_b':'p1',
                       'trm26bxxxx_a':'p2',
                       'trm26bxxxx_b':'p2',
                       'trm37cxxxx_a':'p2',
                       'trm37cxxxx_b':'p2',
                       'sjb7101bxx_a':'p1',
                       'sjb7101bxx_b':'p1',
                       'sjb7102exx_a':'p1',
                       'sjb7102exx_b':'p1',
                       'trm30exxxx_a':'p2',
                       'trm30exxxx_b':'p2',
                       'Salbaxxxxx_a':'outgroup',
                       }

    # Generate data dictionary from NeXus alignment

    dd = NeXus.data_dict_from_file('Concatenated_alignment_variable.nex', pop_assignments)
    
    # Generate frequency spectrum from data dictionary
    
    fs = dadi.Spectrum.from_data_dict(dd, ['p1', 'p2'], [8,8])
    
    # Plot the fs
    #
    # import pylab
    # dadi.Plotting.plot_single_2d_sfs(fs, vmin=0.1)
    # pylab.show()
    
    # Print fs to file
    
    fs.tofile('Salix_2D_B.fs')