### Script for creating migrate parmfiles and pbs submit scripts from a list of models
### Uses template migrate parmfile 'parmfile' and template pbs file 'migrate.pbs'
### Written by Brad Nelson

# Define models
model_set = {}
#                         ->1  ->2  ->3  ->4
model_set['model0000'] = "**** **** **** ****" # Refugia <-> ND, CAS
model_set['model1000'] = "**** 0*0* **** 0*0*" # Refugia  -> ND, Cas         
model_set['model1100'] = "**0* 0*0* 0*** 0*0*" #                      ND !<-> CAS                         
model_set['model1101'] = "**0* 0*0* 0**0 0*0*" #                                  Sal !-> ND     
model_set['model1102'] = "**0* 0*0* 00** 0*0*" #                                  Clw !-> ND
model_set['model1110'] = "**00 0*0* 0*** 0*0*" #                                  Sal !-> Cas
model_set['model1111'] = "**00 0*0* 0**0 0*0*" #                                  Sal !-> Cas; Sal !-> ND
model_set['model1112'] = "**00 0*0* 00** 0*0*" #                                  Sal !-> Cas; Clw !-> ND
model_set['model1120'] = "*00* 0*0* 0*** 0*0*" #                                  Clw !-> Cas
model_set['model1121'] = "*00* 0*0* 0**0 0*0*" #                                  Clw !-> Cas; Sal !-> ND
model_set['model1122'] = "*00* 0*0* 00** 0*0*" #                                  Clw !-> Cas; Clw !-> ND

for model in sorted(model_set):             # Cycle through models
    reader = open('./parmfile', 'r')
    writer = open('./%s.parm' % model, 'w') # Create new parm file for model
    switch = 0
    
	# Make parmfile
    for line in reader:
        if line[0:7] == 'outfile':
            writer.write('outfile=%s_out\n' % model)
            switch += 1
        elif line[0:11] == 'pdf-outfile':
            writer.write('pdf-outfile=%s_out.pdf\n' % model)
            switch += 1
        elif line[0:16] == 'custom-migration':
            writer.write('custom-migration={%s}\n' % model_set[model])
            switch += 1
        elif line[0:17] == 'bayes-priors= MIG':
            writer.write('bayes-priors= MIG UNIFORMPRIOR: 0.000000 25000.000000 2500.000000\n')
            switch += 1
        elif line[0:11] == 'long-sample':
            writer.write('long-sample=10000\n')
            switch += 1
        elif line[0:7] == 'burn-in':
            writer.write('burn-in=1000\n')
            switch += 1
        elif line[0:13] == 'bayes-allfile':
            switch += 1
            writer.write('bayes-allfile=YES:1:bayes_%s_out.gz\n' % model)
        else: writer.write(line)
    if switch != 7: print "error" + model
    reader.close()
    writer.close()
    
	# Make pbs file
    pbsReader = open('./migrate.pbs', 'r')
    pbsWriter = open('./%s.pbs' % model, 'w')
    
    for line in pbsReader:
        if line[0:7] == '#PBS -o':
            pbsWriter.write('#PBS -o %s.out\n' % model)
        elif line[0:7] == '#PBS -N':
            pbsWriter.write('#PBS -N %s\n' % model)
        elif line[0:13] == '#PBS -l nodes':
            if model == 'model0000':
                pbsWriter.write('#PBS -l nodes=20:ppn=4\n')
            else: pbsWriter.write('#PBS -l nodes=20:ppn=4\n')
        elif line[0:16] == '#PBS -l walltime':
            if model == 'model0000':
                pbsWriter.write('#PBS -l walltime=72:00:00\n')
            else: pbsWriter.write('#PBS -l walltime=72:00:00\n')
        elif line[0:15]=='export WORK_DIR':
            pbsWriter.write('export WORK_DIR=/work/bnelson/migrate/%s\n' % model[5:])
        elif line[0:15]=='export EXEC_DIR':
            pbsWriter.write('export EXEC_DIR=/work/bnelson/migrate/%s\n' % model[5:])
        elif line[0:6] == 'mpirun':
            pbsWriter.write('mpirun -np $NPROCS -machinefile $PBS_NODEFILE $EXEC_DIR/migrate-n-mpi $EXEC_DIR/%s.parm -nomenu > $WORK_DIR/%s.dat\n' % (model, model))

        else:
            pbsWriter.write(line)
    pbsReader.close()
    pbsWriter.close()